**dump** - Print internal profile information
=============================================

Usage
--------

.. code::

    e4s-cl profile dump [ NAME ] [ OTHER_NAME ] [...]

Description
--------------

.. automodule:: e4s_cl.cli.commands.profile.dump
